public inbox for cygwin-cvs@sourceware.org
help / color / mirror / Atom feed
From: Corinna Vinschen <corinna@sourceware.org>
To: cygwin-cvs@sourceware.org
Subject: [newlib-cygwin/main] Cygwin: fix two comments in heap.cc and memory_layout.h
Date: Wed, 18 Jan 2023 19:35:25 +0000 (GMT)	[thread overview]
Message-ID: <20230118193525.906873858421@sourceware.org> (raw)

https://sourceware.org/git/gitweb.cgi?p=newlib-cygwin.git;h=3c2ac163da888cf69d855c9becf643dbc6ebd94f

commit 3c2ac163da888cf69d855c9becf643dbc6ebd94f
Author:     Corinna Vinschen <corinna@vinschen.de>
AuthorDate: Wed Jan 18 20:07:54 2023 +0100
Commit:     Corinna Vinschen <corinna@vinschen.de>
CommitDate: Wed Jan 18 20:13:38 2023 +0100

    Cygwin: fix two comments in heap.cc and memory_layout.h
    
    Signed-off-by: Corinna Vinschen <corinna@vinschen.de>

Diff:
---
 winsup/cygwin/local_includes/memory_layout.h | 3 +--
 winsup/cygwin/mm/heap.cc                     | 4 ++--
 2 files changed, 3 insertions(+), 4 deletions(-)

diff --git a/winsup/cygwin/local_includes/memory_layout.h b/winsup/cygwin/local_includes/memory_layout.h
index c763442a9ef4..f8ec80bb58db 100644
--- a/winsup/cygwin/local_includes/memory_layout.h
+++ b/winsup/cygwin/local_includes/memory_layout.h
@@ -16,8 +16,7 @@ details. */
    dynamicbase is accidentally not set in the PE/COFF header of the DLL. */
 #define CYGWIN_DLL_ADDRESS		0x180040000UL
 
-/* Area for non-fixed-address Cygwin-specific shared memory regions.  Fallback
-   for standard shared regions if the can't load at their default address. */
+/* Area for Cygwin-specific shared memory regions. */
 #define SHARED_REGIONS_ADDRESS_LOW	0x1a0000000UL
 #define SHARED_REGIONS_ADDRESS_HIGH	0x200000000UL
 
diff --git a/winsup/cygwin/mm/heap.cc b/winsup/cygwin/mm/heap.cc
index 5b24a197f3b7..72ea486f38f1 100644
--- a/winsup/cygwin/mm/heap.cc
+++ b/winsup/cygwin/mm/heap.cc
@@ -77,11 +77,11 @@ user_heap_info::init ()
 	  if (base)
 	    break;
 
 	  /* Ok, so we are at the 1% which didn't work with 0x20000000 out
 	     of the box.  What we do now is to search for the next free
 	     region which matches our desired heap size.  While doing that,
 	     we keep track of the largest region we found, including the
-	     region starting at 0x20000000. */
+	     region starting at USERHEAP_START. */
 	  while ((ret = VirtualQuery ((LPCVOID) start_address, &mbi,
 				      sizeof mbi)) != 0)
 	    {
@@ -77,11 +77,11 @@ user_heap_info::init ()
 	    break;
 
-	  /* Ok, so we are at the 1% which didn't work with 0x20000000 out
+	  /* Ok, so we are at the 1% which didn't work with USERHEAP_START out
 	     of the box.  What we do now is to search for the next free
 	     region which matches our desired heap size.  While doing that,

                 reply	other threads:[~2023-01-18 19:35 UTC|newest]

Thread overview: [no followups] expand[flat|nested]  mbox.gz  Atom feed

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20230118193525.906873858421@sourceware.org \
    --to=corinna@sourceware.org \
    --cc=cygwin-cvs@sourceware.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).